# Remoras

A simple management system for the Devcamp Hackathon API.

[remora](https://en.wikipedia.org/wiki/Remora)


Changed name from `newton` to `remoras` if you see `newton` or `genius` somewhere this is an artifact
of the old name. `remoras` was available on pypi.

## Remoras Wiki
For more information and usage guides please see the [Wiki](https://github.com/GrayWhaleAI/remoras/wiki) on
our github.

## How to install

### PyPi
`pip install remoras`

[PyPi Link](https://pypi.org/project/remoras/)

### From Source
If you are interested in modifying or contributing to `remoras`

####  Requirements
1. Python >= 3.12


Create a virtual environment for your project:
1. `uv venv` or `python -m venv .venv`
2. Activate the virtual environment `source .venv/bin/activate` (follow OS specific instructions)
3. Clone this repo either into your project or somewhere near by `git clone https://github.com/GrayWhaleAI/remoras.git`
4. With your virtual environment activated `cd newton`, `uv pip install -e .` or `pip install -e .`

> You will ideally see something like `remoras = 1.0.0` installed or something like that

## How to use

See the wiki for updated instructions. Huge facelift / refactor incorperating our 2.0 API has made just flatout removing
the instructions here and pointing to the wiki make more sense.

